==> huawei_site-5.1.0%2B300.tar.gz: README.md <==
<p align="center">
  <h1 align="center">Huawei Site Flutter Plugin</h1>
</p>


<p align="center">
  <a href="https://pub.dev/packages/huawei_site"><img src="https://img.shields.io/pub/v/huawei_site?style=for-the-badge" alt="pub.dev version"></a>
</p>

Huawei Site Flutter Plugin provides adaptation code for HUAWEI Site Kit to use the Flutter platform. With HUAWEI Site Kit, your app can provide users with convenient and secure access to diverse, place-related services.

[Learn More](https://developer.huawei.com/consumer/en/doc/development/HMS-Plugin-Guides/introduction-0000001050181259)

## Installation

Please see [pub.dev](https://pub.dev/packages/huawei_site/install) and [AppGallery Connect Configuration](https://developer.huawei.com/consumer/en/doc/development/HMS-Plugin-Guides/config-agc-0000001050179166).

## Documentation

- [Quick Start](https://developer.huawei.com/consumer/en/doc/development/HMS-Plugin-Guides/overview-0000001056508815)
- [Reference](https://developer.huawei.com/consumer/en/doc/development/HMS-Plugin-References/overview-0000001050426045)

## Questions or Issues

If you have questions about how to use HMS samples, try the following options:

- [Stack Overflow](https://stackoverflow.com/questions/tagged/huawei-mobile-services) is the best place for any programming questions. Be sure to tag your question with **huawei-mobile-services**.
- [Github](https://github.com/HMS-Core/hms-flutter-plugin) is the official repository for these plugins, You can open an issue or submit your ideas.
- [Huawei Developer Forum](https://forums.developer.huawei.com/forumPortal/en/home?fid=0101187876626530001) HMS Core Module is great for general questions, or seeking recommendations and opinions.
- [Huawei Developer Docs](https://developer.huawei.com/consumer/en/doc/overview/HMS-Core-Plugin) is place to official documentation for all HMS Core Kits, you can find detailed documentations in there.

If you run into a bug in our samples, please submit an issue to the [GitHub repository](https://github.com/HMS-Core/hms-flutter-plugin).

## License

Huawei Site Flutter Plugin is licensed under [Apache 2.0 license](LICENCE)

==> huawei_site-5.2.0%2B300.tar.gz: README.md <==
<p align="center">
  <h1 align="center">Huawei Site Flutter Plugin</h1>
</p>


<p align="center">
  <a href="https://pub.dev/packages/huawei_site"><img src="https://img.shields.io/pub/v/huawei_site?style=for-the-badge" alt="pub.dev version"></a>
</p>

Huawei Site Flutter Plugin provides adaptation code for HUAWEI Site Kit to use the Flutter platform. With HUAWEI Site Kit, your app can provide users with convenient and secure access to diverse, place-related services.

[Learn More](https://developer.huawei.com/consumer/en/doc/development/HMS-Plugin-Guides/introduction-0000001050181259?ha_source=hms1)

## Installation

Please see [pub.dev](https://pub.dev/packages/huawei_site/install) and [AppGallery Connect Configuration](https://developer.huawei.com/consumer/en/doc/development/HMS-Plugin-Guides/config-agc-0000001050179166).

## Documentation

- [Quick Start](https://developer.huawei.com/consumer/en/doc/development/HMS-Plugin-Guides/overview-0000001056508815?ha_source=hms1)
- [Reference](https://developer.huawei.com/consumer/en/doc/development/HMS-Plugin-References/overview-0000001050426045?ha_source=hms1)

## Questions or Issues

If you have questions about how to use HMS samples, try the following options:

- [Stack Overflow](https://stackoverflow.com/questions/tagged/huawei-mobile-services) is the best place for any programming questions. Be sure to tag your question with **huawei-mobile-services**.
- [Github](https://github.com/HMS-Core/hms-flutter-plugin) is the official repository for these plugins, You can open an issue or submit your ideas.
- [Huawei Developer Forum](https://forums.developer.huawei.com/forumPortal/en/home?fid=0101187876626530001?ha_source=hms1) HMS Core Module is great for general questions, or seeking recommendations and opinions.
- [Huawei Developer Docs](https://developer.huawei.com/consumer/en/doc/overview/HMS-Core-Plugin?ha_source=hms1) is place to official documentation for all HMS Core Kits, you can find detailed documentations in there.

If you run into a bug in our samples, please submit an issue to the [GitHub repository](https://github.com/HMS-Core/hms-flutter-plugin).

## License

Huawei Site Flutter Plugin is licensed under [Apache 2.0 license](LICENCE)
